Struct OrgKdeKwinServerDecorationManager
pub struct OrgKdeKwinServerDecorationManager { /* private fields */ }wayland and Linux only.Expand description
Server side window decoration manager
This interface allows to coordinate whether the server should create a server-side window decoration around a wl_surface representing a shell surface (wl_shell_surface or similar). By announcing support for this interface the server indicates that it supports server side decorations.
Use in conjunction with zxdg_decoration_manager_v1 is undefined.
See also the Event enum for this interface.
Implementations
impl OrgKdeKwinServerDecorationManager
impl OrgKdeKwinServerDecorationManager
pub fn create<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> OrgKdeKwinServerDecoration
pub fn create<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> OrgKdeKwinServerDecoration
Create a server-side decoration object for a given surface
When a client creates a server-side decoration object it indicates that it supports the protocol. The client is supposed to tell the server whether it wants server-side decorations or will provide client-side decorations.
If the client does not create a server-side decoration object for a surface the server interprets this as lack of support for this protocol and considers it as client-side decorated. Nevertheless a client-side decorated surface should use this protocol to indicate to the server that it does not want a server-side deco.